@@ -6,13 +6,18 @@
 
 from __future__ import print_function
 
+try:
+    from base64 import encodebytes as base64_encode
+except ImportError:
+    from base64 import encodestring as base64_encode
+
 import json
 import mimetypes
 import os
 import struct
+import sys
 import warnings
 
-from IPython.core.formatters import _safe_get_formatter_method
 from IPython.utils.py3compat import (string_types, cast_bytes_py2, cast_unicode,
                                      unicode_type)
 from IPython.testing.skipdoctest import skip_doctest
@@ -185,6 +190,9 @@ def display_pretty(*objs, **kwargs):
 
 def display_html(*objs, **kwargs):
     """Display the HTML representation of an object.
+    
+    Note: If raw=False and the object does not have a HTML
+    representation, no HTML will be shown.
 
     Parameters
     ----------
@@ -637,7 +645,7 @@ class Image(DisplayObject):
     _FMT_PNG = u'png'
     _ACCEPTABLE_EMBEDDINGS = [_FMT_JPEG, _FMT_PNG]
 
-    def __init__(self, data=None, url=None, filename=None, format=u'png',
+    def __init__(self, data=None, url=None, filename=None, format=None,
                  embed=None, width=None, height=None, retina=False,
                  unconfined=False, metadata=None):
         """Create a PNG/JPEG image object given raw data.
@@ -670,9 +678,9 @@ class Image(DisplayObject):
 
             Note that QtConsole is not able to display images if `embed` is set to `False`
         width : int
-            Width to which to constrain the image in html
+            Width in pixels to which to constrain the image in html
         height : int
-            Height to which to constrain the image in html
+            Height in pixels to which to constrain the image in html
         retina : bool
             Automatically set the width and height to half of the measured
             width and height.
@@ -714,17 +722,27 @@ class Image(DisplayObject):
         else:
             ext = None
 
-        if ext is not None:
-            format = ext.lower()
-            if ext == u'jpg' or ext == u'jpeg':
-                format = self._FMT_JPEG
-            if ext == u'png':
-                format = self._FMT_PNG
-        elif isinstance(data, bytes) and format == 'png':
-            # infer image type from image data header,
-            # only if format might not have been specified.
-            if data[:2] == _JPEG:
-                format = 'jpeg'
+        if format is None:
+            if ext is not None:
+                if ext == u'jpg' or ext == u'jpeg':
+                    format = self._FMT_JPEG
+                if ext == u'png':
+                    format = self._FMT_PNG
+                else:
+                    format = ext.lower()
+            elif isinstance(data, bytes):
+                # infer image type from image data header,
+                # only if format has not been specified.
+                if data[:2] == _JPEG:
+                    format = self._FMT_JPEG
+
+        # failed to detect format, default png
+        if format is None:
+            format = 'png'
+
+        if format.lower() == 'jpg':
+            # jpg->jpeg
+            format = self._FMT_JPEG
 
         self.format = unicode_type(format).lower()
         self.embed = embed if embed is not None else (url is None)
@@ -807,7 +825,7 @@ class Image(DisplayObject):
 
 class Video(DisplayObject):
 
-    def __init__(self, data=None, url=None, filename=None, embed=None, mimetype=None):
+    def __init__(self, data=None, url=None, filename=None, embed=False, mimetype=None):
         """Create a video object given raw data or an URL.
 
         When this object is returned by an input cell or passed to the
@@ -817,41 +835,54 @@ class Video(DisplayObject):
         Parameters
         ----------
         data : unicode, str or bytes
-            The raw image data or a URL or filename to load the data from.
-            This always results in embedded image data.
+            The raw video data or a URL or filename to load the data from.
+            Raw data will require passing `embed=True`.
         url : unicode
-            A URL to download the data from. If you specify `url=`,
-            the image data will not be embedded unless you also specify `embed=True`.
+            A URL for the video. If you specify `url=`,
+            the image data will not be embedded.
         filename : unicode
-            Path to a local file to load the data from.
-            Videos from a file are always embedded.
+            Path to a local file containing the video.
+            Will be interpreted as a local URL unless `embed=True`.
         embed : bool
-            Should the image data be embedded using a data URI (True) or be
-            loaded using an <img> tag. Set this to True if you want the image
-            to be viewable later with no internet connection in the notebook.
+            Should the video be embedded using a data URI (True) or be
+            loaded using a <video> tag (False).
 
-            Default is `True`, unless the keyword argument `url` is set, then
-            default value is `False`.
+            Since videos are large, embedding them should be avoided, if possible.
+            You must confirm embedding as your intention by passing `embed=True`.
+
+            Local files can be displayed with URLs without embedding the content, via::
+
+                Video('./video.mp4')
 
-            Note that QtConsole is not able to display images if `embed` is set to `False`
         mimetype: unicode
-            Specify the mimetype in case you load in a encoded video.
+            Specify the mimetype for embedded videos.
+            Default will be guessed from file extension, if available.
+
         Examples
         --------
+
         Video('https://archive.org/download/Sita_Sings_the_Blues/Sita_Sings_the_Blues_small.mp4')
         Video('path/to/video.mp4')
-        Video('path/to/video.mp4', embed=False)
+        Video('path/to/video.mp4', embed=True)
+        Video(b'raw-videodata', embed=True)
         """
-        if url is None and (data.startswith('http') or data.startswith('https')):
+        if url is None and isinstance(data, string_types) and data.startswith(('http:', 'https:')):
             url = data
             data = None
-            embed = False
         elif os.path.exists(data):
             filename = data
             data = None
+        
+        if data and not embed:
+            msg = ''.join([
+                "To embed videos, you must pass embed=True ",
+                "(this may make your notebook files huge)\n",
+                "Consider passing Video(url='...')",
+            ])
+            raise ValueError(msg)
 
         self.mimetype = mimetype
-        self.embed = embed if embed is not None else (filename is not None)
+        self.embed = embed
         super(Video, self).__init__(data=data, url=url, filename=filename)
 
     def _repr_html_(self):
@@ -863,20 +894,27 @@ class Video(DisplayObject):
       Your browser does not support the <code>video</code> element.
     </video>""".format(url)
             return output
-        # Embedded videos uses base64 encoded videos.
+        
+        # Embedded videos are base64-encoded.
+        mimetype = self.mimetype
         if self.filename is not None:
-            mimetypes.init()
-            mimetype, encoding = mimetypes.guess_type(self.filename)
-
-            video = open(self.filename, 'rb').read()
-            video_encoded = video.encode('base64')
+            if not mimetype:
+                mimetype, _ = mimetypes.guess_type(self.filename)
+            
+            with open(self.filename, 'rb') as f:
+                video = f.read()
         else:
-            video_encoded = self.data
-            mimetype = self.mimetype
+            video = self.data
+        if isinstance(video, unicode_type):
+            # unicode input is already b64-encoded
+            b64_video = video
+        else:
+            b64_video = base64_encode(video).decode('ascii').rstrip()
+        
         output = """<video controls>
  <source src="data:{0};base64,{1}" type="{0}">
  Your browser does not support the video tag.
- </video>""".format(mimetype, video_encoded)
+ </video>""".format(mimetype, b64_video)
         return output
 
     def reload(self):
@@ -901,11 +939,10 @@ def clear_output(wait=False):
     if InteractiveShell.initialized():
         InteractiveShell.instance().display_pub.clear_output(wait)
     else:
-        from IPython.utils import io
-        print('\033[2K\r', file=io.stdout, end='')
-        io.stdout.flush()
-        print('\033[2K\r', file=io.stderr, end='')
-        io.stderr.flush()
+        print('\033[2K\r', end='')
+        sys.stdout.flush()
+        print('\033[2K\r', end='')
+        sys.stderr.flush()
 
 
 @skip_doctest
@@ -930,9 +967,9 @@ def set_matplotlib_formats(*formats, **kwargs):
     """
     from IPython.core.interactiveshell import InteractiveShell
     from IPython.core.pylabtools import select_figure_formats
-    from IPython.kernel.zmq.pylab.config import InlineBackend
     # build kwargs, starting with InlineBackend config
     kw = {}
+    from ipykernel.pylab.config import InlineBackend
     cfg = InlineBackend.instance()
     kw.update(cfg.print_figure_kwargs)
     kw.update(**kwargs)
@@ -961,7 +998,7 @@ def set_matplotlib_close(close=True):
         Should all matplotlib figures be automatically closed after each cell is
         run?
     """
-    from IPython.kernel.zmq.pylab.config import InlineBackend
+    from ipykernel.pylab.config import InlineBackend
     cfg = InlineBackend.instance()
     cfg.close_figures = close
 
