@@ -16,11 +16,10 @@ import glob
 from warnings import warn
 from hashlib import md5
 
-import IPython
-from IPython.testing.skipdoctest import skip_doctest
 from IPython.utils.process import system
-from IPython.utils.importstring import import_item
 from IPython.utils import py3compat
+from IPython.utils.decorators import undoc
+
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
@@ -32,7 +31,6 @@ def _writable_dir(path):
     return os.path.isdir(path) and os.access(path, os.W_OK)
 
 if sys.platform == 'win32':
-    @skip_doctest
     def _get_long_path_name(path):
         """Get a long path name (expand ~) on Windows using ctypes.
 
@@ -75,15 +73,21 @@ def get_long_path_name(path):
 
 def unquote_filename(name, win32=(sys.platform=='win32')):
     """ On Windows, remove leading and trailing quotes from filenames.
+
+    This function has been deprecated and should not be used any more:
+    unquoting is now taken care of by :func:`IPython.utils.process.arg_split`.
     """
+    warn("'unquote_filename' is deprecated since IPython 5.0 and should not "
+         "be used anymore", DeprecationWarning)
     if win32:
         if name.startswith(("'", '"')) and name.endswith(("'", '"')):
             name = name[1:-1]
     return name
 
+
 def compress_user(path):
     """Reverse of :func:`os.path.expanduser`
-    """    
+    """
     path = py3compat.unicode_to_str(path, sys.getfilesystemencoding())
     home = os.path.expanduser('~')
     if path.startswith(home):
@@ -95,18 +99,13 @@ def get_py_filename(name, force_win32=None):
 
     If the given name is not a file, it adds '.py' and searches again.
     Raises IOError with an informative message if the file isn't found.
-
-    On Windows, apply Windows semantics to the filename. In particular, remove
-    any quoting that has been applied to it. This option can be forced for
-    testing purposes.
     """
 
     name = os.path.expanduser(name)
-    if force_win32 is None:
-        win32 = (sys.platform == 'win32')
-    else:
-        win32 = force_win32
-    name = unquote_filename(name, win32=win32)
+    if force_win32 is not None:
+        warn("The 'force_win32' argument to 'get_py_filename' is deprecated "
+             "since IPython 5.0 and should not be used anymore",
+            DeprecationWarning)
     if not os.path.isfile(name) and not name.endswith('.py'):
         name += '.py'
     if os.path.isfile(name):
@@ -255,111 +254,35 @@ def get_xdg_cache_dir():
     return None
 
 
+@undoc
 def get_ipython_dir():
-    """Get the IPython directory for this platform and user.
-
-    This uses the logic in `get_home_dir` to find the home directory
-    and then adds .ipython to the end of the path.
-    """
-
-    env = os.environ
-    pjoin = os.path.join
-
-
-    ipdir_def = '.ipython'
-
-    home_dir = get_home_dir()
-    xdg_dir = get_xdg_dir()
-    
-    # import pdb; pdb.set_trace()  # dbg
-    if 'IPYTHON_DIR' in env:
-        warn('The environment variable IPYTHON_DIR is deprecated. '
-                'Please use IPYTHONDIR instead.')
-    ipdir = env.get('IPYTHONDIR', env.get('IPYTHON_DIR', None))
-    if ipdir is None:
-        # not set explicitly, use ~/.ipython
-        ipdir = pjoin(home_dir, ipdir_def)
-        if xdg_dir:
-            # Several IPython versions (up to 1.x) defaulted to .config/ipython
-            # on Linux. We have decided to go back to using .ipython everywhere
-            xdg_ipdir = pjoin(xdg_dir, 'ipython')
-
-            if _writable_dir(xdg_ipdir):
-                cu = compress_user
-                if os.path.exists(ipdir):
-                    warn(('Ignoring {0} in favour of {1}. Remove {0} to '
-                        'get rid of this message').format(cu(xdg_ipdir), cu(ipdir)))
-                elif os.path.islink(xdg_ipdir):
-                    warn(('{0} is deprecated. Move link to {1} to '
-                        'get rid of this message').format(cu(xdg_ipdir), cu(ipdir)))
-                else:
-                    warn('Moving {0} to {1}'.format(cu(xdg_ipdir), cu(ipdir)))
-                    shutil.move(xdg_ipdir, ipdir)
-
-    ipdir = os.path.normpath(os.path.expanduser(ipdir))
-
-    if os.path.exists(ipdir) and not _writable_dir(ipdir):
-        # ipdir exists, but is not writable
-        warn("IPython dir '{0}' is not a writable location,"
-                " using a temp directory.".format(ipdir))
-        ipdir = tempfile.mkdtemp()
-    elif not os.path.exists(ipdir):
-        parent = os.path.dirname(ipdir)
-        if not _writable_dir(parent):
-            # ipdir does not exist and parent isn't writable
-            warn("IPython parent '{0}' is not a writable location,"
-                    " using a temp directory.".format(parent))
-            ipdir = tempfile.mkdtemp()
-
-    return py3compat.cast_unicode(ipdir, fs_encoding)
-
+    warn("get_ipython_dir has moved to the IPython.paths module")
+    from IPython.paths import get_ipython_dir
+    return get_ipython_dir()
 
+@undoc
 def get_ipython_cache_dir():
-    """Get the cache directory it is created if it does not exist."""
-    xdgdir = get_xdg_cache_dir()
-    if xdgdir is None:
-        return get_ipython_dir()
-    ipdir = os.path.join(xdgdir, "ipython")
-    if not os.path.exists(ipdir) and _writable_dir(xdgdir):
-        ensure_dir_exists(ipdir)
-    elif not _writable_dir(xdgdir):
-        return get_ipython_dir()
-
-    return py3compat.cast_unicode(ipdir, fs_encoding)
-
+    warn("get_ipython_cache_dir has moved to the IPython.paths module")
+    from IPython.paths import get_ipython_cache_dir
+    return get_ipython_cache_dir()
 
+@undoc
 def get_ipython_package_dir():
-    """Get the base directory where IPython itself is installed."""
-    ipdir = os.path.dirname(IPython.__file__)
-    return py3compat.cast_unicode(ipdir, fs_encoding)
-
+    warn("get_ipython_package_dir has moved to the IPython.paths module")
+    from IPython.paths import get_ipython_package_dir
+    return get_ipython_package_dir()
 
+@undoc
 def get_ipython_module_path(module_str):
-    """Find the path to an IPython module in this version of IPython.
-
-    This will always find the version of the module that is in this importable
-    IPython package. This will always return the path to the ``.py``
-    version of the module.
-    """
-    if module_str == 'IPython':
-        return os.path.join(get_ipython_package_dir(), '__init__.py')
-    mod = import_item(module_str)
-    the_path = mod.__file__.replace('.pyc', '.py')
-    the_path = the_path.replace('.pyo', '.py')
-    return py3compat.cast_unicode(the_path, fs_encoding)
+    warn("get_ipython_module_path has moved to the IPython.paths module")
+    from IPython.paths import get_ipython_module_path
+    return get_ipython_module_path(module_str)
 
+@undoc
 def locate_profile(profile='default'):
-    """Find the path to the folder associated with a given profile.
-    
-    I.e. find $IPYTHONDIR/profile_whatever.
-    """
-    from IPython.core.profiledir import ProfileDir, ProfileDirError
-    try:
-        pd = ProfileDir.find_profile_dir_by_name(get_ipython_dir(), profile)
-    except ProfileDirError:
-        # IOError makes more sense when people are expecting a path
-        raise IOError("Couldn't find profile %r" % profile)
-    return pd.location
+    warn("locate_profile has moved to the IPython.paths module")
+    from IPython.paths import locate_profile
+    return locate_profile(profile=profile)
 
 def expand_path(s):
     """Expand $VARS and ~names in a string, like a shell
@@ -444,83 +367,14 @@ def target_update(target,deps,cmd):
     if target_outdated(target,deps):
         system(cmd)
 
+@undoc
 def filehash(path):
     """Make an MD5 hash of a file, ignoring any differences in line
     ending characters."""
+    warn("filehash() is deprecated")
     with open(path, "rU") as f:
         return md5(py3compat.str_to_bytes(f.read())).hexdigest()
 
-# If the config is unmodified from the default, we'll just delete it.
-# These are consistent for 0.10.x, thankfully. We're not going to worry about
-# older versions.
-old_config_md5 = {'ipy_user_conf.py': 'fc108bedff4b9a00f91fa0a5999140d3',
-                  'ipythonrc': '12a68954f3403eea2eec09dc8fe5a9b5'}
-
-def check_for_old_config(ipython_dir=None):
-    """Check for old config files, and present a warning if they exist.
-
-    A link to the docs of the new config is included in the message.
-
-    This should mitigate confusion with the transition to the new
-    config system in 0.11.
-    """
-    if ipython_dir is None:
-        ipython_dir = get_ipython_dir()
-
-    old_configs = ['ipy_user_conf.py', 'ipythonrc', 'ipython_config.py']
-    warned = False
-    for cfg in old_configs:
-        f = os.path.join(ipython_dir, cfg)
-        if os.path.exists(f):
-            if filehash(f) == old_config_md5.get(cfg, ''):
-                os.unlink(f)
-            else:
-                warn("Found old IPython config file {!r} (modified by user)".format(f))
-                warned = True
-
-    if warned:
-        warn("""
-  The IPython configuration system has changed as of 0.11, and these files will
-  be ignored. See http://ipython.github.com/ipython-doc/dev/config for details
-  of the new config system.
-  To start configuring IPython, do `ipython profile create`, and edit
-  `ipython_config.py` in <ipython_dir>/profile_default.
-  If you need to leave the old config files in place for an older version of
-  IPython and want to suppress this warning message, set
-  `c.InteractiveShellApp.ignore_old_config=True` in the new config.""")
-
-def get_security_file(filename, profile='default'):
-    """Return the absolute path of a security file given by filename and profile
-    
-    This allows users and developers to find security files without
-    knowledge of the IPython directory structure. The search path
-    will be ['.', profile.security_dir]
-    
-    Parameters
-    ----------
-    
-    filename : str
-        The file to be found. If it is passed as an absolute path, it will
-        simply be returned.
-    profile : str [default: 'default']
-        The name of the profile to search.  Leaving this unspecified
-        The file to be found. If it is passed as an absolute path, fname will
-        simply be returned.
-    
-    Returns
-    -------
-    Raises :exc:`IOError` if file not found or returns absolute path to file.
-    """
-    # import here, because profiledir also imports from utils.path
-    from IPython.core.profiledir import ProfileDir
-    try:
-        pd = ProfileDir.find_profile_dir_by_name(get_ipython_dir(), profile)
-    except Exception:
-        # will raise ProfileDirError if no such profile
-        raise IOError("Profile %r not found")
-    return filefind(filename, ['.', pd.security_dir])
-
-
 ENOLINK = 1998
 
 def link(src, dst):
